pub struct PrepDetails {
pub prep_instruction: PrepInstruction,
pub prep_owner: PrepOwner,
}Expand description
PrepDetails : Preparation instructions and who is responsible for the preparation.
Fields
prep_instruction: PrepInstructionprep_owner: PrepOwnerImplementations
sourceimpl PrepDetails
impl PrepDetails
sourcepub fn new(
prep_instruction: PrepInstruction,
prep_owner: PrepOwner
) -> PrepDetails
pub fn new(
prep_instruction: PrepInstruction,
prep_owner: PrepOwner
) -> PrepDetails
Preparation instructions and who is responsible for the preparation.